@@ -1,4 +1,3 @@
-/* $XFree86: xc/lib/Xxf86dga/XF86DGA2.c,v 1.23 2003/05/05 20:42:30 tsi Exp $ */
 /*
 
 Copyright (c) 1995  Jon Tombs
@@ -15,11 +14,9 @@ Copyright (c) 1995,1996  The XFree86 Project, Inc
 #include <os2.h>
 #endif
 
-#define NEED_EVENTS
-#define NEED_REPLIES
 #include <X11/Xlibint.h>
-#include <X11/extensions/xf86dga.h>
-#include <X11/extensions/xf86dgastr.h>
+#include <X11/extensions/Xxf86dga.h>
+#include <X11/extensions/xf86dgaproto.h>
 #include <X11/extensions/Xext.h>
 #include <X11/extensions/extutil.h>
 #include <stdio.h>
@@ -710,7 +707,6 @@ void XDGAKeyEventToXKeyEvent(
 }
 
 #include <X11/Xmd.h>
-#include <X11/extensions/xf86dga.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <fcntl.h>
